#ifndef _DOO_AUXILIARY_SEGMENTATION_FUNCTIONS_HEADER
#define _DOO_AUXILIARY_SEGMENTATION_FUNCTIONS_HEADER

#include "image.h"
#include "iconcomp.h"
#include "segmcommon.h"

namespace diva
{

namespace imgproc
{

/*!\defgroup CompoundEntities Compound Entities (Definitions & Detection Algorithms)
 */

/*!\defgroup DocumentColumns Document Columns
 * \brief Include header file(s): <doolib/auxsegmfunc.h>.
 * \ingroup CompoundEntities
 */

/*!\defgroup DocumentColumnsUtil Utility Classes& Functions
 * \ingroup DocumentColumns
 */

/*!\addtogroup AuxiliaryCF Auxiliary Classes& Functions
 */
//@{
//@}
/*!\addtogroup AuxiliaryCFSegmentation Document Segmentation-related
 * \ingroup AuxiliaryCF
 */
//@{
bool IsBoundingBoxCharacterLike_RotationInvariant(const BoundingBox2D* b, int mintextheight, int mintextwidth);

bool IsPotentialCharacter_RotationInvariant(const ConComp& c, int mintextheight, int mintextwidth);

//@}

/*!\addtogroup DominantCharacterSize Detection of Dominant Character Size/ Dominant Font
 * \ingroup AuxiliaryCF
 */
//@{
void ComputeAvgCharacterSize(const ConComp* comps, int numcomp, int minxsize, int minysize, int& xsize, int& ysize);

void ComputeAvgCharacterSize_RotationInvariant(const ConComp* comps, int numcomp, int minxsize, int minysize, int& xsize, int& ysize);

//@}

//-----------------------------------------------------------------------------------------
//             implementations of various inline/template functions
//-----------------------------------------------------------------------------------------

/*!
 * \note Like all _RotationInvariant testing functions, this is a very basic test which
 * actually works reliably only for page rotation angles located near multiples of 90 degrees!
 */
inline bool IsBoundingBoxCharacterLike_RotationInvariant(const BoundingBox2D* b, int mintextheight, int mintextwidth)
{
    //IMPORTANT: the factor 10 here is in direct relation with the factor 0.1 in
    //IsPotentialCharacter_RotationInvariant(), so update accordingly !
    if (((b->Width() >= mintextwidth) && (b->Height() >= mintextheight)) || ((b->Width() >= mintextheight) && (b->Height() >= mintextwidth)))
    {
        if (b->Width() <= b->Height())
        {
            if (b->Width() >= b->Height() * 0.1) return true;
        }
        else
        {
            if (b->Height() >= b->Width() * 0.1) return true;
        }
    }
    return false;
}

/*!
 * \note Like all _RotationInvariant testing functions, this is a very basic test which
 * actually works reliably only for page rotation angles located near multiples of 90 degrees!
 */
inline bool IsPotentialCharacter_RotationInvariant(const ConComp& c, int mintextheight, int mintextwidth)
{
    //IMPORTANT: the factor 0.1 here is in direct relation with the factor 10 in
    //IsBoundingBoxCharacterLike_RotationInvariant(), so update accordingly !
    if (IsBoundingBoxCharacterLike_RotationInvariant(c.GetBoundingBox(), mintextheight, mintextwidth))
    {
        if ((c.numpixel <= c.GetBoundingBox()->Area() * 0.9) && (c.numpixel >= c.GetBoundingBox()->Area() * 0.12))
        {
            return true;
        }
    }
    return false;
}

} //namespace

} //namespace

#endif
