#ifndef _DOO_DESKEW_HEADER
#define _DOO_DESKEW_HEADER

namespace diva
{

namespace imgproc
{

/*!\addtogroup ImageManipulation Image Manipulation
 */
//@{
//@}
/*!\addtogroup GeometricTransformations Geometric Transformations (Translations, Rotations, Scaling)
 * \ingroup ImageManipulation
 */
//@{
template<class Point2DSimpleImpl1, class Point2DSimpleImpl2>
void RotatePointAroundCenter(Point2DSimpleImpl1& point, const Point2DSimpleImpl2& center, const double sinangle, const double cosangle);

//@}

//--------------------------------------------------------------------------------
//                      IMPLEMENTATIONS of INLINE/ TEMPLATE functions
//--------------------------------------------------------------------------------

/*!Rotates a given point around a center by \c angle degrees (>0 = counter-clockwise).
 * \note Note that the angle is indirectly given through its sine and cosine =>
 * greater efficiency for multiple calls due to re-using sin/cos values
 */
template<class Point2DSimpleImpl1, class Point2DSimpleImpl2>
inline void RotatePointAroundCenter(Point2DSimpleImpl1& point, const Point2DSimpleImpl2& center, const double sinangle, const double cosangle)
{
    const double x = point.x - center.x;
    const double y = point.y - center.y;
    point.x = x * cosangle - y * sinangle + center.x;
    point.y = x * sinangle + y * cosangle + center.y;
}

} //namespace

} //namespace

#endif //_DESKEW_HEADER
