#ifndef _DOO_SEGMENTATION_COMMON_HEADER
#define _DOO_SEGMENTATION_COMMON_HEADER

//STANDARD
#include <cmath>
#include <algorithm>

namespace diva
{

namespace imgproc
{

/*!\addtogroup Segmentation_Interfaces General Purpose Interfaces
 */
//@{
/*!Class meant to provide information about the global properties of the processed
 * documents.
 */
class GlobalDocumentProperties
{
public:
    static double GetMinimumTextHeightCm();
    static double GetMinimumTextWidthCm();
    static unsigned int GetMinimumTextHeightPix(double dpi = 0);
    static unsigned int GetMinimumTextWidthPix(double dpi = 0);
};

//@}

//-------------------------------------------------------------------------------
//                 implementations of various inline functions
//-------------------------------------------------------------------------------

/*!Returns the assumed minimum possible (i.e. legible by an average human) text character height
 * (in centimeters).
 */
inline double GlobalDocumentProperties::GetMinimumTextHeightCm()
{
    //this is just a basic assumption! - lowered from 0.09 on 26.05.2011 due to a few
    //real life examples involving parts of text lines typed in minuscules failing to meet
    //this requirement using the _average_ height
    return 0.08;
}

/*!Returns the assumed minimum possible (i.e. legible by an average human) text character width
 * (in centimeters).
 */
inline double GlobalDocumentProperties::GetMinimumTextWidthCm()
{
    //this is just a basic assumption!
    return 0.00225;
}

/*!Returns the minimum possible (i.e. legible by an average human) text character height
 * (in pixels), given the scanning resolution (in dots per inch!) of a certain page.
 * If the scanning resolution is not specified (i.e.=0), it assumes it is a computer-
 * produced document, for which the minimum text height is set to be 6 pixels.
 */
inline unsigned int GlobalDocumentProperties::GetMinimumTextHeightPix(double dpi)
{
    return (std::max(((unsigned int)std::floor(GlobalDocumentProperties::GetMinimumTextHeightCm() * dpi / 2.54)), (unsigned int)9));
}

/*!Returns the minimum possible (i.e. legible by an average human) text character width
 * (in pixels), given the scanning resolution (in dots per inch!) of a certain page.
 * If the scanning resolution is not specified (i.e.=0), it assumes it is a computer-
 * produced document, for which the minimum text height is set to be 2 pixels.
 */
inline unsigned int GlobalDocumentProperties::GetMinimumTextWidthPix(double dpi)
{
    return (std::max(((unsigned int)std::floor(GlobalDocumentProperties::GetMinimumTextWidthCm() * dpi / 2.54)), (unsigned int)6));
}

}

}

#endif
